@@ -1,11 +1,13 @@
-use crate::api::activity::activity::PgcrScaper;
+use crate::api::activity::activity::{PGCR, PgcrScraper};
 use crate::api::DestinyAPI::ApiInterface;
 use crate::api::user::BungieUser::{BungieUser, DestinyPlatform};
 use crate::api::clan::Clan::Clan;
+use crate::api::manifest::manifest::{Manifest, ManifestEntityType};
+use crate::api::user::DestinyCharacter::DestinyCharacter;
 
-mod api;
+pub mod api;
 
-pub async fn get_api() -> ApiInterface {
+async fn get_api() -> ApiInterface {
     ApiInterface::new("c57f52d5d071428fb8ff8684ba938212", true).await
 }
 
@@ -13,7 +15,7 @@ pub async fn get_api() -> ApiInterface {
 async fn get_user() {
     println!("-----Get User By ID-----");
     let user = get_api().await.get_user_by_id(String::from("4611686018468620320"), DestinyPlatform::Steam).await.unwrap();
-    print_user(user);
+    print_user(&user);
 }
 
 #[tokio::test]
@@ -38,10 +40,26 @@ async fn get_user_by_name_one() {
 }
 
 #[tokio::test]
-async fn get_user_by_name_and_discriminator() {
+async fn get_user_by_name_and_discriminator_and_characters() {
     println!("-----Get User By Name And Discriminator-----");
     let user = BungieUser::get_user_by_name_and_discrim_with_platform(&get_api().await.client, String::from("dec4234#9904"), DestinyPlatform::All).await.unwrap();
-    print_user(user);
+    print_user(&user);
+
+    println!("\n-----Get Characters-----");
+    get_characters(&user).await;
+}
+
+async fn get_characters(user: &BungieUser) {
+    for c in user.get_characters(&get_api().await.client).await.unwrap() {
+        println!("\n-----Character-----");
+        print_character(c);
+    }
+}
+
+fn print_character(c: DestinyCharacter) {
+    println!("ID - {}", c.characterId);
+    println!("Date Last Played - {}", c.dateLastPlayed.unwrap());
+    println!("Light Level - {}", c.light);
 }
 
 #[tokio::test]
@@ -54,7 +72,7 @@ async fn test_name_splitting() {
     }
 }
 
-fn print_user(user: BungieUser) {
+fn print_user(user: &BungieUser) {
     println!();
     println!("--------Destiny Membership Info--------");
     println!("ID - {}", user.primary.id);
@@ -75,7 +93,7 @@ fn print_user(user: BungieUser) {
 
 
     print!("Applicable Membership Types - [");
-    for i in user.primary.membership_types {
+    for i in &user.primary.membership_types {
         print!(" {},", i);
     }
     println!(" ]\n");
@@ -169,5 +187,21 @@ async fn clan_members() {
 
 #[tokio::test]
 pub async fn test_pgcr_one() {
-    let pgcr = PgcrScaper::new(&get_api().await.client).await.get_pgcr(1).await.unwrap();
+    let pgcr = PgcrScraper::new(&get_api().await.client).await.get_pgcr(1).await.unwrap();
+    print_pgcr(&pgcr);
+}
+
+fn print_pgcr(pgcr: &PGCR) {
+    println!("Assists Display Value - {}", pgcr.entries.get(0).unwrap().values.completed.basic.displayValue);
+}
+
+#[tokio::test]
+pub async fn manifest_test() {
+    let man = Manifest::new(get_api().await.client);
+
+    let vec = vec!["144602215", "1735777505", "1935470627", "1943323491", "2996146975", "392767087", "4244567218"];
+
+    for s in vec {
+        println!("{} = {}", s, man.manifest_get(ManifestEntityType::ITEMSTAT, String::from(s)).await.unwrap());
+    }
 }
\ No newline at end of file
